@@ -15,14 +15,14 @@ from tests.basetest import Basetest
 @jp.SetRoute("/bye", name = "bye")
 def bye_function(_request):
     wp = jp.WebPage()
-    wp.add(jp.P(text='Hello there!', classes='text-5xl m-2'))
+    wp.add(jp.P(text='Bye bye!', classes='text-5xl m-2'))
     return wp
 
 @jp.SetRoute("/hello", name = "hello")
 def hello_function(request):
     wp = jp.WebPage()
     wp.add(jp.P(text='Hello there!', classes='text-5xl m-2'))
-    print("request  = ", request.url_for("bye"))
+    print("request  = ", request.url_for("hello"))
     return wp
 
 class TestRouteAndUrlFor(Basetest):
@@ -49,10 +49,15 @@ class TestRouteAndUrlFor(Basetest):
         test url for functionality
         '''
         app = jp.app
+        # see https://www.starlette.io/testclient/
         with  TestClient(app) as client:
             response=client.get("/hello")    
             self.assertEqual(200,response.status_code)
             debug=self.debug
+            debug=True
+            lines=response.text.split("\n")
             if debug:
                 print(response.text)
-            self.assertTrue(response.text.startswith("<!DOCTYPE html>"))
\ No newline at end of file
+                print(f"{len(lines)} lines")
+            self.assertTrue(response.text.startswith("<!DOCTYPE html>"))
+            self.assertTrue(len(lines)<500)
\ No newline at end of file
